@@ -5,8 +5,9 @@ train = dict(
     img_prefix=f'{prefix}/imgs',
     ann_file=f'{prefix}/instances_train.txt',
     loader=dict(
-        type='HardDiskLoader',
+        type='AnnFileLoader',
         repeat=100,
+        file_format='txt',
         parser=dict(
             type='LineJsonParser', keys=['file_name', 'annotations', 'text'])),
     pipeline=None,
@@ -17,8 +18,9 @@ test = dict(
     img_prefix=f'{prefix}/imgs',
     ann_file=f'{prefix}/instances_test.txt',
     loader=dict(
-        type='HardDiskLoader',
+        type='AnnFileLoader',
         repeat=1,
+        file_format='txt',
         parser=dict(
             type='LineStrParser',
             keys=['filename', 'text'],
