@@ -38,7 +38,7 @@ test_pipeline = [
                 keys=['img'],
                 meta_keys=[
                     'filename', 'ori_shape', 'img_shape', 'valid_ratio',
-                    'resize_shape'
+                    'resize_shape', 'img_norm_cfg', 'ori_filename'
                 ]),
         ])
 ]
