@@ -1,5 +1,7 @@
+# optimizer
 optimizer = dict(type='Adam', lr=1e-4)
 optimizer_config = dict(grad_clip=None)
+# learning policy
 lr_config = dict(
     policy='step',
     step=[16, 18],
@@ -7,4 +9,6 @@ lr_config = dict(
     warmup_iters=1,
     warmup_ratio=0.001,
     warmup_by_epoch=True)
-total_epochs = 20
+# running settings
+runner = dict(type='EpochBasedRunner', max_epochs=20)
+checkpoint_config = dict(interval=1)
