@@ -1,6 +1,6 @@
 _base_ = [
+    '../../_base_/default_runtime.py',
     '../../_base_/schedules/schedule_adam_600e.py',
-    '../../_base_/runtime_10e.py',
     '../../_base_/det_models/panet_r18_fpem_ffm.py',
     '../../_base_/det_datasets/ctw1500.py',
     '../../_base_/det_pipelines/panet_pipeline.py'
