@@ -3,7 +3,7 @@ import numpy as np
 from mmcv import rescale_size
 from mmcv.parallel import DataContainer as DC
 from mmdet.datasets.builder import PIPELINES
-from mmdet.datasets.pipelines.formating import DefaultFormatBundle, to_tensor
+from mmdet.datasets.pipelines.formatting import DefaultFormatBundle, to_tensor
 
 
 @PIPELINES.register_module()
