@@ -1,15 +1,17 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import math
 
 import cv2
+import mmcv
 import numpy as np
-import Polygon as plg
 import torchvision.transforms as transforms
-from PIL import Image
-
-import mmocr.core.evaluation.utils as eval_utils
 from mmdet.core import BitmapMasks, PolygonMasks
 from mmdet.datasets.builder import PIPELINES
 from mmdet.datasets.pipelines.transforms import Resize
+from PIL import Image
+from shapely.geometry import Polygon as plg
+
+import mmocr.core.evaluation.utils as eval_utils
 from mmocr.utils import check_argument
 
 
@@ -89,10 +91,11 @@ class RandomCropInstances:
 
         for idx, bbox in enumerate(bboxes):
             poly = eval_utils.box2polygon(bbox)
-            area, inters = eval_utils.poly_intersection(poly, canvas_poly)
+            area, inters = eval_utils.poly_intersection(
+                poly, canvas_poly, return_poly=True)
             if area == 0:
                 continue
-            xmin, xmax, ymin, ymax = inters.boundingBox()
+            xmin, ymin, xmax, ymax = inters.bounds
             kept_bboxes += [
                 np.array(
                     [xmin - tl[0], ymin - tl[1], xmax - tl[0], ymax - tl[1]],
@@ -587,7 +590,7 @@ class RandomRotatePolyInstances:
             (h_ind, w_ind) = (np.random.randint(0, h * 7 // 8),
                               np.random.randint(0, w * 7 // 8))
             img_cut = img[h_ind:(h_ind + h // 9), w_ind:(w_ind + w // 9)]
-            img_cut = cv2.resize(img_cut, (canvas_size[1], canvas_size[0]))
+            img_cut = mmcv.imresize(img_cut, (canvas_size[1], canvas_size[0]))
             mask = cv2.warpAffine(
                 mask,
                 rotation_matrix, (canvas_size[1], canvas_size[0]),
@@ -670,7 +673,7 @@ class SquareResizePad:
             t_w = self.target_size if h <= w else int(w * self.target_size / h)
         else:
             t_h = t_w = self.target_size
-        img = cv2.resize(img, (t_w, t_h))
+        img = mmcv.imresize(img, (t_w, t_h))
         return img, (t_h, t_w)
 
     def square_pad(self, img):
@@ -685,7 +688,7 @@ class SquareResizePad:
             (h_ind, w_ind) = (np.random.randint(0, h * 7 // 8),
                               np.random.randint(0, w * 7 // 8))
             img_cut = img[h_ind:(h_ind + h // 9), w_ind:(w_ind + w // 9)]
-            expand_img = cv2.resize(img_cut, (pad_size, pad_size))
+            expand_img = mmcv.imresize(img_cut, (pad_size, pad_size))
         if h > w:
             y0, x0 = 0, (h - w) // 2
         else:
@@ -758,7 +761,7 @@ class RandomScaling:
         scales = self.size * 1.0 / max(h, w) * aspect_ratio
         scales = np.array([scales, scales])
         out_size = (int(h * scales[1]), int(w * scales[0]))
-        image = cv2.resize(image, out_size[::-1])
+        image = mmcv.imresize(image, out_size[::-1])
 
         results['img'] = image
         results['img_shape'] = image.shape
@@ -845,28 +848,28 @@ class RandomCropFlip:
 
             pts = np.stack([[xmin, xmax, xmax, xmin],
                             [ymin, ymin, ymax, ymax]]).T.astype(np.int32)
-            pp = plg.Polygon(pts)
+            pp = plg(pts)
             fail_flag = False
             for polygon in polygons:
-                ppi = plg.Polygon(polygon[0].reshape(-1, 2))
-                ppiou, _ = eval_utils.poly_intersection(ppi, pp)
-                if np.abs(ppiou - float(ppi.area())) > self.epsilon and \
+                ppi = plg(polygon[0].reshape(-1, 2))
+                ppiou = eval_utils.poly_intersection(ppi, pp)
+                if np.abs(ppiou - float(ppi.area)) > self.epsilon and \
                         np.abs(ppiou) > self.epsilon:
                     fail_flag = True
                     break
-                elif np.abs(ppiou - float(ppi.area())) < self.epsilon:
+                elif np.abs(ppiou - float(ppi.area)) < self.epsilon:
                     polys_new.append(polygon)
                 else:
                     polys_keep.append(polygon)
 
             for polygon in ignore_polygons:
-                ppi = plg.Polygon(polygon[0].reshape(-1, 2))
-                ppiou, _ = eval_utils.poly_intersection(ppi, pp)
-                if np.abs(ppiou - float(ppi.area())) > self.epsilon and \
+                ppi = plg(polygon[0].reshape(-1, 2))
+                ppiou = eval_utils.poly_intersection(ppi, pp)
+                if np.abs(ppiou - float(ppi.area)) > self.epsilon and \
                         np.abs(ppiou) > self.epsilon:
                     fail_flag = True
                     break
-                elif np.abs(ppiou - float(ppi.area())) < self.epsilon:
+                elif np.abs(ppiou - float(ppi.area)) < self.epsilon:
                     ign_polys_new.append(polygon)
                 else:
                     ign_polys_keep.append(polygon)
@@ -964,3 +967,54 @@ class RandomCropFlip:
         h_axis = np.where(h_array == 0)[0]
         w_axis = np.where(w_array == 0)[0]
         return h_axis, w_axis
+
+
+@PIPELINES.register_module()
+class PyramidRescale:
+    """Resize the image to the base shape, downsample it with gaussian pyramid,
+    and rescale it back to original size.
+
+    Adapted from https://github.com/FangShancheng/ABINet.
+
+    Args:
+        factor (int): The decay factor from base size, or the number of
+            downsampling operations from the base layer.
+        base_shape (tuple(int)): The shape of the base layer of the pyramid.
+        randomize_factor (bool): If True, the final factor would be a random
+            integer in [0, factor].
+
+    :Required Keys:
+        - | ``img`` (ndarray): The input image.
+
+    :Affected Keys:
+        :Modified:
+            - | ``img`` (ndarray): The modified image.
+    """
+
+    def __init__(self, factor=4, base_shape=(128, 512), randomize_factor=True):
+        assert isinstance(factor, int)
+        assert isinstance(base_shape, list) or isinstance(base_shape, tuple)
+        assert len(base_shape) == 2
+        assert isinstance(randomize_factor, bool)
+        self.factor = factor if not randomize_factor else np.random.randint(
+            0, factor + 1)
+        self.base_w, self.base_h = base_shape
+
+    def __call__(self, results):
+        assert 'img' in results
+        if self.factor == 0:
+            return results
+        img = results['img']
+        src_h, src_w = img.shape[:2]
+        scale_img = mmcv.imresize(img, (self.base_w, self.base_h))
+        for _ in range(self.factor):
+            scale_img = cv2.pyrDown(scale_img)
+        scale_img = mmcv.imresize(scale_img, (src_w, src_h))
+        results['img'] = scale_img
+        return results
+
+    def __repr__(self):
+        repr_str = self.__class__.__name__
+        repr_str += f'(factor={self.factor}, '
+        repr_str += f'basew={self.basew}, baseh={self.baseh})'
+        return repr_str
