@@ -1,13 +1,14 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import numpy as np
 import torch.nn as nn
 import torch.nn.functional as F
-from mmcv.cnn import uniform_init, xavier_init
+from mmcv.runner import BaseModule
 
 from mmocr.models.builder import DECODERS
 
 
 @DECODERS.register_module()
-class FCDecoder(nn.Module):
+class FCDecoder(BaseModule):
     """FC Decoder class for Ner.
 
     Args:
@@ -19,13 +20,16 @@ class FCDecoder(nn.Module):
     def __init__(self,
                  num_labels=None,
                  hidden_dropout_prob=0.1,
-                 hidden_size=768):
-        super().__init__()
+                 hidden_size=768,
+                 init_cfg=[
+                     dict(type='Xavier', layer='Conv2d'),
+                     dict(type='Uniform', layer='BatchNorm2d')
+                 ]):
+        super().__init__(init_cfg=init_cfg)
         self.num_labels = num_labels
 
         self.dropout = nn.Dropout(hidden_dropout_prob)
         self.classifier = nn.Linear(hidden_size, self.num_labels)
-        self.init_weights()
 
     def forward(self, outputs):
         sequence_output = outputs[0]
@@ -35,11 +39,3 @@ class FCDecoder(nn.Module):
         preds = softmax.detach().cpu().numpy()
         preds = np.argmax(preds, axis=2).tolist()
         return logits, preds
-
-    def init_weights(self):
-
-        for m in self.modules():
-            if isinstance(m, nn.Conv2d):
-                xavier_init(m)
-            elif isinstance(m, nn.BatchNorm2d):
-                uniform_init(m)
