@@ -1,14 +1,20 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import torch.nn as nn
-from mmcv.cnn import kaiming_init, uniform_init
+from mmcv.runner import BaseModule
 
-from mmdet.models.builder import BACKBONES
+from mmocr.models.builder import BACKBONES
 
 
 @BACKBONES.register_module()
-class NRTRModalityTransform(nn.Module):
+class NRTRModalityTransform(BaseModule):
 
-    def __init__(self, input_channels=3, input_height=32):
-        super().__init__()
+    def __init__(self,
+                 input_channels=3,
+                 init_cfg=[
+                     dict(type='Kaiming', layer='Conv2d'),
+                     dict(type='Uniform', layer='BatchNorm2d')
+                 ]):
+        super().__init__(init_cfg=init_cfg)
 
         self.conv_1 = nn.Conv2d(
             in_channels=input_channels,
@@ -28,16 +34,7 @@ class NRTRModalityTransform(nn.Module):
         self.relu_2 = nn.ReLU(True)
         self.bn_2 = nn.BatchNorm2d(64)
 
-        feat_height = input_height // 4
-
-        self.linear = nn.Linear(64 * feat_height, 512)
-
-    def init_weights(self, pretrained=None):
-        for m in self.modules():
-            if isinstance(m, nn.Conv2d):
-                kaiming_init(m)
-            elif isinstance(m, nn.BatchNorm2d):
-                uniform_init(m)
+        self.linear = nn.Linear(512, 512)
 
     def forward(self, x):
         x = self.conv_1(x)
@@ -49,7 +46,11 @@ class NRTRModalityTransform(nn.Module):
         x = self.bn_2(x)
 
         n, c, h, w = x.size()
+
         x = x.permute(0, 3, 2, 1).contiguous().view(n, w, h * c)
+
         x = self.linear(x)
+
         x = x.permute(0, 2, 1).contiguous().view(n, -1, 1, w)
+
         return x
