@@ -3,6 +3,7 @@ from .abinet import ABINet
 from .base import BaseRecognizer
 from .crnn import CRNNNet
 from .encode_decode_recognizer import EncodeDecodeRecognizer
+from .master import MASTER
 from .nrtr import NRTR
 from .robust_scanner import RobustScanner
 from .sar import SARNet
@@ -11,5 +12,5 @@ from .seg_recognizer import SegRecognizer
 
 __all__ = [
     'BaseRecognizer', 'EncodeDecodeRecognizer', 'CRNNNet', 'SARNet', 'NRTR',
-    'SegRecognizer', 'RobustScanner', 'SATRN', 'ABINet'
+    'SegRecognizer', 'RobustScanner', 'SATRN', 'ABINet', 'MASTER'
 ]
