@@ -9,7 +9,7 @@ from .collect_env import collect_env
 from .data_convert_util import convert_annotations
 from .fileio import list_from_file, list_to_file
 from .img_util import drop_orientation, is_not_png
-from .lmdb_util import lmdb_converter
+from .lmdb_util import recog2lmdb
 from .logger import get_root_logger
 from .model import revert_sync_batchnorm
 from .setup_env import setup_multi_processes
@@ -22,5 +22,5 @@ __all__ = [
     'convert_annotations', 'is_not_png', 'list_to_file', 'list_from_file',
     'is_on_same_line', 'stitch_boxes_into_lines', 'StringStrip',
     'revert_sync_batchnorm', 'bezier_to_polygon', 'sort_points',
-    'setup_multi_processes'
+    'setup_multi_processes', 'recog2lmdb'
 ]
