@@ -201,6 +201,13 @@ class MMOCR:
                 'dbnet/'
                 'dbnet_r50dcnv2_fpnc_sbn_1200e_icdar2015_20211025-9fe3b590.pth'
             },
+            'DBPP_r50': {
+                'config':
+                'dbnetpp/dbnetpp_r50dcnv2_fpnc_1200e_icdar2015.py',
+                'ckpt':
+                'dbnet/'
+                'dbnetpp_r50dcnv2_fpnc_1200e_icdar2015-20220502-d7a76fff.pth'
+            },
             'DRRG': {
                 'config':
                 'drrg/drrg_r50_fpn_unet_1200e_ctw1500.py',
@@ -316,6 +323,10 @@ class MMOCR:
                 'config': 'abinet/abinet_academic.py',
                 'ckpt': 'abinet/abinet_academic-f718abf6.pth'
             },
+            'ABINet_Vision': {
+                'config': 'abinet/abinet_vision_only_academic.py',
+                'ckpt': 'abinet/abinet_vision_only_academic-e6b9ea89.pth'
+            },
             'SEG': {
                 'config': 'seg/seg_r31_1by16_fpnocr_academic.py',
                 'ckpt': 'seg/seg_r31_1by16_fpnocr_academic-72235b11.pth'
@@ -324,14 +335,18 @@ class MMOCR:
                 'config': 'tps/crnn_tps_academic_dataset.py',
                 'ckpt': 'tps/crnn_tps_academic_dataset_20210510-d221a905.pth'
             },
-            'Tesseract': {}
+            'Tesseract': {},
+            'MASTER': {
+                'config': 'master/master_r31_12e_ST_MJ_SA.py',
+                'ckpt': 'master/master_r31_12e_ST_MJ_SA-787edd36.pth'
+            }
         }
 
         kie_models = {
             'SDMGR': {
                 'config': 'sdmgr/sdmgr_unet16_60e_wildreceipt.py',
                 'ckpt':
-                'sdmgr/sdmgr_unet16_60e_wildreceipt_20210520-7489e6de.pth'
+                'sdmgr/sdmgr_unet16_60e_wildreceipt_20220706-57c220a6.pth'
             }
         }
 
